calc_invsqrt_mat: Calculate matrix inverse square root for a covariance matrix

View source: R/calc_sqrt_mat.R

calc_invsqrt_matR Documentation

Calculate matrix inverse square root for a covariance matrix

Description

Calculate matrix inverse square root for a covariance matrix

Usage

calc_invsqrt_mat(A)

Arguments

A

covariance matrix


qtl2pleio documentation built on April 26, 2026, 1:06 a.m.