calc_lrt_tib: Calculate a likelihood ratio test statistic from the output...

View source: R/calc_lrt_tib.R

calc_lrt_tibR Documentation

Calculate a likelihood ratio test statistic from the output of scan_pvl()

Description

Calculate a likelihood ratio test statistic from the output of scan_pvl()

Usage

calc_lrt_tib(scan_pvl_out)

Arguments

scan_pvl_out

outputted tibble from scan_pvl

Value

a number, the (log) likelihood ratio test statistic

Examples

rep(paste0('Marker', 1:3), times = 3) -> marker1
rep(paste0('Marker', 1:3), each = 3) -> marker2
runif(9, -1, 0) -> ll
tibble::tibble(marker1, marker2, ll) -> scan_out
calc_lrt_tib(scan_out)

qtl2pleio documentation built on April 26, 2026, 1:06 a.m.