check_identical: Check whether a vector, x, has all its entries equal to its...

View source: R/utils.R

check_identicalR Documentation

Check whether a vector, x, has all its entries equal to its first entry

Description

Check whether a vector, x, has all its entries equal to its first entry

Usage

check_identical(x)

Arguments

x

a vector

Value

a logical indicating whether all vector entries are the same

Examples

x <- 1:5
check_identical(x)
y <- rep(1, 5)
check_identical(y)

qtl2pleio documentation built on April 26, 2026, 1:06 a.m.