check_missingness: Check for missingness in phenotypes or covariates

View source: R/utils.R

check_missingnessR Documentation

Check for missingness in phenotypes or covariates

Description

We use 'is.finite' from base R to identify those subjects that have one or more missing values in 'input_matrix'. We then return a character vector of subjects that have no missingness in 'input_matrix'.

Usage

check_missingness(input_matrix)

Arguments

input_matrix

phenotypes or covariates matrix

Value

character vector of subjects that have no missingness


qtl2pleio documentation built on April 26, 2026, 1:06 a.m.