prep_mytab: Prepare mytab object for use within scan_pvl R code

View source: R/prep_mytab.R

prep_mytabR Documentation

Prepare mytab object for use within scan_pvl R code

Description

Prepare mytab object for use within scan_pvl R code

Usage

prep_mytab(d_size, n_snp, pvl = TRUE)

Arguments

d_size

an integer, the number of traits

n_snp

an integer, the number of markers

pvl

logical indicating whether to output dataframe with all d-tuples for a d-QTL scan, or only those models that examine one marker at a time.

Value

a data.frame with d_size + 1 columns and (n_snp)^d_size rows. Last column is NA and named loglik.

Examples

prep_mytab(2, 10)

qtl2pleio documentation built on April 26, 2026, 1:06 a.m.